.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xfunction
=========

Defined in ``xtensor/xfunction.hpp``

.. doxygenclass:: xt::xfunction
   :project: xtensor
   :members:

Defined in ``xtensor/xmath.hpp``

.. doxygenfunction:: make_lambda_xfunction
   :project: xtensor
